%global xslver $(rpm -q --queryformat "%%{VERSION}" docbook-style-xsl)

%bcond_with wolfssl

Name:              netatalk
Version:           3.2.9
Release:           1%{?dist}
Summary:           Open Source Apple Filing Protocol(AFP) File Server
License:           GPL-1.0-or-later AND GPL-2.0-only AND GPL-2.0-or-later AND LGPLv2+ AND BSD AND FSFUL AND MIT
URL:               http://netatalk.sourceforge.net
Source0:           https://download.sourceforge.net/netatalk/netatalk-%{version}.tar.xz
Source1:           netatalk.pam-system-auth

ExcludeArch: %{ix86}

BuildRequires:     avahi-devel
BuildRequires:     bison
BuildRequires:     coreutils
BuildRequires:     cracklib-devel
BuildRequires:     dbus-devel
BuildRequires:     dbus-glib-devel
BuildRequires:     docbook-style-xsl
BuildRequires:     findutils
BuildRequires:     flex
BuildRequires:     gcc
BuildRequires:     grep
BuildRequires:     krb5-devel
BuildRequires:     libacl-devel
BuildRequires:     libattr-devel
BuildRequires:     libdb-devel
BuildRequires:     libevent-devel
BuildRequires:     libgcrypt-devel
BuildRequires:     libretls-devel
BuildRequires:     libtalloc-devel
BuildRequires:     libtdb-devel
BuildRequires:     libxslt
BuildRequires:     mariadb-connector-c-devel
BuildRequires:     meson
BuildRequires:     openldap-devel
BuildRequires:     openssl-devel
BuildRequires:     pam-devel
BuildRequires:     perl-generators
BuildRequires:     perl-interpreter
BuildRequires:     procps
BuildRequires:     procps-ng
BuildRequires:     quota-devel
BuildRequires:     rpm
BuildRequires:     sed
BuildRequires:     systemd
BuildRequires:     systemtap-sdt-devel
BuildRequires:     tracker3
BuildRequires:     tracker3-devel
%{?with_wolfssl:BuildRequires:     wolfssl-devel}

Requires:     dconf
Requires:     python3-dbus
%{?systemd_requires}

Conflicts: jday

%description
Netatalk is a freely-available Open Source AFP file server. A *NIX/*BSD
system running Netatalk is capable of serving many Macintosh clients
simultaneously as an AppleShare file server (AFP).

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
This package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p 1

rm -rf include/wolfssl

sed -i 's\install: true\install: false\' doc/ja/manual/meson.build
sed -i 's\doc/netatalk\doc/netatalk/htmldoc\' doc/manual/meson.build

sed -E -i 's|^(ExecStart=.*)|\1\nRuntimeDirectory=lock/netatalk|' distrib/initscripts/service.systemd.tmpl

%build
%meson \
        --localstatedir=%{_localstatedir}/lib                                  \
        -Ddefault_library=shared                                               \
        -Dwith-manual=true                                                     \
        -Dwith-rpath=false                                                     \
        -Dwith-docbook-path=%{_datadir}/sgml/docbook/xsl-stylesheets-%{xslver} \
        -Dwith-overwrite=true                                                  \
        -Dwith-pgp-uam=true                                                    \
        -Dwith-lockfile-path=%{_rundir}/lock/netatalk/netatalk                 \
        -Dwith-tcp-wrappers=false                                              \
        -Dwith-tests=true                                                      \
        -Dwith-dbus-sysconf-path=%{_sysconfdir}/dbus-1/system.d                \
        -Dwith-pkgconfdir-path=%{_sysconfdir}/netatalk                         \
        -Dwith-init-style=redhat-systemd                                       \
        -Dwith-init-hooks=false                                                \
        -Dwith-uams-path=%{_libdir}/netatalk                                   \
        -Dwith-embedded-ssl=false                                              \
        -Dwith-ssl-override=false

%meson_build

%install
%meson_install

install -Dpm644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pam.d/netatalk

rm -rf %{buildroot}%{_prefix}%{_sysconfdir}

find %{buildroot} \( -name '*.la' -o -name '*.a' \) -type f -delete -print

ln -sf ../README %{buildroot}/var/lib/netatalk/CNID/README

%check
%meson_test

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%files
%license COPYING COPYRIGHT
%doc CONTRIBUTORS NEWS INSTALL.md README.md SECURITY.md
%doc %{_pkgdocdir}/htmldoc

%dir %{_sysconfdir}/netatalk
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/netatalk-dbus.conf
%config(noreplace) %{_sysconfdir}/netatalk/afp.conf
%config(noreplace) %{_sysconfdir}/netatalk/dbus-session.conf
%config(noreplace) %{_sysconfdir}/netatalk/extmap.conf
%config(noreplace) %{_sysconfdir}/pam.d/netatalk

%{_sbindir}/afpd
%{_sbindir}/cnid_dbd
%{_sbindir}/cnid_metad
%{_sbindir}/netatalk
%{_bindir}/ad
%{_bindir}/afpldaptest
%{_bindir}/afppasswd
%{_bindir}/afpstats
%{_bindir}/apple_dump
%{_bindir}/asip-status
%{_bindir}/dbd
%{_bindir}/macusers

%dir %{_libdir}/netatalk
%{_libdir}/netatalk/uams_*.so
%{_libdir}/libatalk.so.18{,.*}

%{_mandir}/man1/ad.1*
%{_mandir}/man1/afpldaptest.1*
%{_mandir}/man1/afppasswd.1*
%{_mandir}/man1/afpstats.1*
%{_mandir}/man1/apple_dump.1*
%{_mandir}/man1/asip-status.1*
%{_mandir}/man1/dbd.1*
%{_mandir}/man1/macusers.1*
%{_mandir}/man5/*
%{_mandir}/man8/*

%{_unitdir}/netatalk.service
%{_localstatedir}/lib/netatalk

%files devel
%{_bindir}/netatalk-config
%{_mandir}/man1/netatalk-config.1*
%dir %{_includedir}/atalk
%{_includedir}/atalk/*.h
%{_libdir}/libatalk.so

%changelog
* Tue Dec 10 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.2.9-1
- [Type] security
- [DESC] Fix CVE-2024-38439, CVE-2024-38441 and CVE-2024-38440

* Tue Sep 3 2024 Ze Zhang <bbrucezhang@tencent.com> - 3.1.18-2
- [Type] other
- [DESC] Remove not used macors

* Mon Jul 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.18-1
- initial build
